@@ -1,5 +1,5 @@
 """The TurtLSystems Python package (https://pypi.org/project/TurtLSystems) is a tool and educational
 code toy for generating images and animations of Lindenmayer system (L-system) patterns via turtle graphics."""
 
-from TurtLSystems.core import init, draw, wait, lsystem
-__all__ = ['init', 'draw', 'wait', 'lsystem']
+from TurtLSystems.core import init, draw, wait, lsystem, Exit
+__all__ = ['init', 'draw', 'wait', 'lsystem', 'Exit']
