@@ -1,9 +1,17 @@
 """TurtLSystems examples (https://pypi.org/project/TurtLSystems)."""
 
-from TurtLSystems import draw
-draw('+A', 'A B-A-B B A+B+A,', 5, 60, 7, 2, (200, 220, 255), None, (36, 8, 107),
-     red_increment=2, gif='example.gif', max_frames=250, duration=30)
-# try:
+from TurtLSystems import init, draw, wait, Exit
+try:
+    init(...)
+    draw(...)
+    wait()
+except Exit:
+    pass
+
+# from TurtLSystems import init, draw,
+# draw('+A', 'A B-A-B B A+B+A,', 5, 60, 7, 2, (200, 220, 255), None, (36, 8, 107),
+#      red_increment=2, gif='example.gif', max_frames=250, duration=30)
+# # try:
 
 # draw('X', 'X 0F-[[X]+X]-1F[+FX]-X F FF',
 #      5, angle=10, length=5, thickness=2, heading=90, position=(0, -200),
